==> haskell-neat-interpolation-0.3.2.2-16-armv7h.pkg.tar.xz: usr/share/haskell/register/haskell-neat-interpolation.sh <==
#!/bin/sh
export PATH='/usr/lib/distcc/bin:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: neat-interpolation
version: 0.3.2.2
id: neat-interpolation-0.3.2.2-93GVGYA2sBA9F7bzIkBSAH
key: neat-interpolation-0.3.2.2-93GVGYA2sBA9F7bzIkBSAH
license: MIT
copyright: (c) 2013, Nikita Volkov
maintainer: Nikita Volkov <nikita.y.volkov@mail.ru>
author: Nikita Volkov <nikita.y.volkov@mail.ru>
homepage: https://github.com/nikita-volkov/neat-interpolation
synopsis: A quasiquoter for neat and simple multiline text interpolation
description:
    A quasiquoter for producing Text values with support for
    a simple interpolation of input values.
    It removes the excessive indentation from the input and
    accurately manages the indentation of all lines of the interpolated variables.
category: String, QuasiQuotes
abi: 367f95d47f2abd56461f83a262df4752
exposed: True
exposed-modules:
    NeatInterpolation
hidden-modules: NeatInterpolation.Parsing NeatInterpolation.String
import-dirs: /usr/lib/ghc-8.6.1/site-local/neat-interpolation-0.3.2.2
library-dirs: /usr/lib/ghc-8.6.1/site-local/neat-interpolation-0.3.2.2
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/arm-linux-ghc-8.6.1/neat-interpolation-0.3.2.2
hs-libraries: HSneat-interpolation-0.3.2.2-93GVGYA2sBA9F7bzIkBSAH
depends:
    base-4.12.0.0 base-prelude-1.3-4ZZNNsW3hao94Bjea11y2s
    megaparsec-6.5.0-3jMAfeTH3SCGgkXRBfZZuQ template-haskell-2.14.0.0
    text-1.2.3.1
haddock-interfaces: /usr/share/doc/haskell-neat-interpolation/html/neat-interpolation.haddock
haddock-html: /usr/share/doc/haskell-neat-interpolation/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-neat-interpolation-0.3.2.2-17-armv7h.pkg.tar.xz: usr/share/haskell/register/haskell-neat-interpolation.sh <==
#!/bin/sh
export PATH='/usr/lib/distcc/bin:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: neat-interpolation
version: 0.3.2.2
id: neat-interpolation-0.3.2.2-5uYQzCy1fEDJpZo5wGzHbp
key: neat-interpolation-0.3.2.2-5uYQzCy1fEDJpZo5wGzHbp
license: MIT
copyright: (c) 2013, Nikita Volkov
maintainer: Nikita Volkov <nikita.y.volkov@mail.ru>
author: Nikita Volkov <nikita.y.volkov@mail.ru>
homepage: https://github.com/nikita-volkov/neat-interpolation
synopsis: A quasiquoter for neat and simple multiline text interpolation
description:
    A quasiquoter for producing Text values with support for
    a simple interpolation of input values.
    It removes the excessive indentation from the input and
    accurately manages the indentation of all lines of the interpolated variables.
category: String, QuasiQuotes
abi: e73553fa7d2ef9de9df30887b35d29dc
exposed: True
exposed-modules:
    NeatInterpolation
hidden-modules: NeatInterpolation.Parsing NeatInterpolation.String
import-dirs: /usr/lib/ghc-8.6.1/site-local/neat-interpolation-0.3.2.2
library-dirs: /usr/lib/ghc-8.6.1/site-local/neat-interpolation-0.3.2.2
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/arm-linux-ghc-8.6.1/neat-interpolation-0.3.2.2
hs-libraries: HSneat-interpolation-0.3.2.2-5uYQzCy1fEDJpZo5wGzHbp
depends:
    base-4.12.0.0 base-prelude-1.3-4ZZNNsW3hao94Bjea11y2s
    megaparsec-6.5.0-H8uHgj645yksoUPNfpvnU template-haskell-2.14.0.0
    text-1.2.3.1
haddock-interfaces: /usr/share/doc/haskell-neat-interpolation/html/neat-interpolation.haddock
haddock-html: /usr/share/doc/haskell-neat-interpolation/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
